=======
Credits
=======

Development Lead
----------------

* Edson Cavalcanti Neto <profedsoncavalcanti@gmail.com>

Contributors
------------
* Afranio Rebouças <afraniofilho@hotmail.com>
* Alan Portela <alan.p.bandeira@gmail.com>
* Alex Jason Maramaldo <alexmaramaldo@gmail.com>
* Charles Roberto Stempniak <charles@automa.com.br>
* Dennis braga <bragadennis.dev@gmail.com>
* Francisco Alex Girão <fco.alex.girao@gmail.com>
* Julio Chilela <julio.chilela@angolacables.co.ao>
* Lirio Ramalho <lirio.ramalheira@angolacables.co.ao>
* Raul Medeiros <raul.medeiros.rm@gmail.com>
* Thiago Augusto <ferreirathiago@me.com>